searchNodes=[{"doc":"OpentelemetryProcessPropagator provides helpers for dealing with context propagation across process boundaries. Context Propagation Erlang and Elixir do not have a mechanism for transparently passing context between processes. This requires the user to explicitly pass data between processes. In order to continue a trace across processes, the user must start a new span and pass it to the spawned process. span_ctx = OpenTelemetry.Tracer . start_span ( &quot;child&quot; ) ctx = OpenTelemetry.Ctx . get_current ( ) task = Task . async ( fn -&gt; OpenTelemetry.Ctx . attach ( ctx ) OpenTelemetry.Tracer . set_current_span ( span_ctx ) # do work here OpenTelemetry.Tracer . end_span ( span_ctx ) end ) _result = Task . await ( task ) Reverse Propagation It's not always possible to have full control over traces, such as when using telemetry events emitted from a library you don't control to create a span. In such cases, a mechanism to fetch a context from a calling process is necessary. This is effectively context propagation in reverse. As an example, Ecto uses the Task module to execute preloads which are each a separate query. Since a task is a spawned process, creating an otel span results in orphan spans. To correctly connect these spans we must find the otel context which spawned the process. Usage Example of using fetch_parent_ctx/1 to find a parent context. OpenTelemetry . with_span :span_started_in_your_app do # some span being created in a process spawned by a library # you don&#39;t control, e.g. Ecto preloads Task . async ( fn -&gt; parent_ctx = OpentelemetryProcessPropagator . fetch_parent_ctx ( :&quot;$callers&quot; ) OpenTelemetry.Ctx . attach ( parent_ctx ) attrs = %{ some_attr : :from_telemetry_event } span = OpenTelemetry.Tracer . start_span ( :span_created_in_lib , %{ attributes : attrs } ) OpenTelemetry.Span . end_span ( span ) end ) end ? with_span ( span_started_in_your_app , , fun ( ) -&gt; %% some span being created in a process spawned by a library %% you don&#39;t control proc_lib : spawn_link ( fun ( ) -&gt; Tracer = opentelemetry : get_tracer ( test_tracer ) , ParentCtx = opentelemetry_process_propagator : fetch_parent_ctx ( ) , otel_ctx : attach ( ParentCtx ) , Span = otel_tracer : start_span ( Tracer , span_created_in_lib , ) , otel_tracer : end_span ( Span ) . ) . end","ref":"OpentelemetryProcessPropagator.html","title":"OpentelemetryProcessPropagator","type":"module"},{"doc":"Attempt to fetch an otel context from a give pid.","ref":"OpentelemetryProcessPropagator.html#fetch_ctx/1","title":"OpentelemetryProcessPropagator.fetch_ctx/1","type":"function"},{"doc":"Attempt to find an otel context in the spawning process. This is equivalent to calling fetch_parent_ctx(1, :&quot;$ancestors&quot;)","ref":"OpentelemetryProcessPropagator.html#fetch_parent_ctx/0","title":"OpentelemetryProcessPropagator.fetch_parent_ctx/0","type":"function"},{"doc":"Attempt to find an otel context in a spawning process within n number of parent processes","ref":"OpentelemetryProcessPropagator.html#fetch_parent_ctx/1","title":"OpentelemetryProcessPropagator.fetch_parent_ctx/1","type":"function"},{"doc":"Attempt to find an otel context under a given process dictionary key within n number of parent processes. The first context found will be returned. Processes spawned by proc_lib are stored under :&quot;$ancestors . The Elixir Task module uses the :&quot;$callers key.","ref":"OpentelemetryProcessPropagator.html#fetch_parent_ctx/2","title":"OpentelemetryProcessPropagator.fetch_parent_ctx/2","type":"function"},{"doc":"OpentelemetryProcessPropagator.Task provides a set of extensions to the Task module to reduce some boilerplate in propagating OpenTelemetry contexts across process boundaries. Since these are extensions rather than a replacement of Elixir's module, this library can be aliased into a file without concern for creating spans where you do not want them. Each Task function is replicated with two variants: *_with_span and *_with_linked_span . Each of these variations has a specific use case. The original implementation for each function automatically propagates the current context. * - propagates the current context *_with_span - propagates the current context and starts a new child span. *_with_linked_span - propagates the current context and starts a new linked span. Module Redefinement This module does not redefine the Task module, instead providing a wrapper of the module, so this functionality will not globally modify the default behavior of the Task module. Usage defmodule MyApp do require OpenTelemetry.Tracer alias OpentelemetryProcessPropagator.Task def traced_task_with_existing_span do Task . async ( fn -&gt; :ok end ) |&gt; Task . await ( ) end def traced_task_with_new_span do Task . async_with_span ( :span_name , %{ attributes : %{ a : &quot;b&quot; } } , fn -&gt; Tracer . set_attribute ( :c , &quot;d&quot; ) :ok end ) |&gt; Task . await ( ) end def traced_task_with_new_linked_span do Task . async_with_linked_span ( :span_name , %{ attributes : %{ a : &quot;b&quot; } } , fn -&gt; Tracer . set_attribute ( :c , &quot;d&quot; ) :ok end ) |&gt; Task . await ( ) end end","ref":"OpentelemetryProcessPropagator.Task.html","title":"OpentelemetryProcessPropagator.Task","type":"module"},{"doc":"Starts a task with the current OpenTelemetry.Ctx.t/0 that can be awaited on. See Task.async/1 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async/1","title":"OpentelemetryProcessPropagator.Task.async/1","type":"function"},{"doc":"Starts a task with the current OpenTelemetry.Ctx.t/0 that can be awaited on. See Task.async/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async/3","title":"OpentelemetryProcessPropagator.Task.async/3","type":"function"},{"doc":"Returns a stream that runs the given function fun concurrently on each element in enumerable with the current OpenTelemetry.Ctx.t/0 attached. See Task.async_stream/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream/3","title":"OpentelemetryProcessPropagator.Task.async_stream/3","type":"function"},{"doc":"Returns a stream where the given function ( module and function ) is mapped concurrently on each element in enumerable with the current OpenTelemetry.Ctx.t/0 attached. See Task.async_stream/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream/5","title":"OpentelemetryProcessPropagator.Task.async_stream/5","type":"function"},{"doc":"Returns a stream that runs the given function fun concurrently on each element in enumerable with a new linked span. See Task.async_stream/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.async_stream_with_linked_span/5","type":"function"},{"doc":"Returns a stream where the given function ( module and function ) is mapped concurrently on each element in enumerable with a new linked span. See Task.async_stream/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream_with_linked_span/7","title":"OpentelemetryProcessPropagator.Task.async_stream_with_linked_span/7","type":"function"},{"doc":"Returns a stream that runs the given function fun concurrently on each element in enumerable with a new child span. See Task.async_stream/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream_with_span/5","title":"OpentelemetryProcessPropagator.Task.async_stream_with_span/5","type":"function"},{"doc":"Returns a stream where the given function ( module and function ) is mapped concurrently on each element in enumerable with a new child span. See Task.async_stream/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream_with_span/7","title":"OpentelemetryProcessPropagator.Task.async_stream_with_span/7","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on. See Task.async/1 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_with_linked_span/3","title":"OpentelemetryProcessPropagator.Task.async_with_linked_span/3","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on. See Task.async/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.async_with_linked_span/5","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on. See Task.async/1 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_with_span/3","title":"OpentelemetryProcessPropagator.Task.async_with_span/3","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on. See Task.async/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_with_span/5","title":"OpentelemetryProcessPropagator.Task.async_with_span/5","type":"function"},{"doc":"See Task.await/1 .","ref":"OpentelemetryProcessPropagator.Task.html#await/1","title":"OpentelemetryProcessPropagator.Task.await/1","type":"function"},{"doc":"See Task.await/2 .","ref":"OpentelemetryProcessPropagator.Task.html#await/2","title":"OpentelemetryProcessPropagator.Task.await/2","type":"function"},{"doc":"See Task.await_many/1 .","ref":"OpentelemetryProcessPropagator.Task.html#await_many/1","title":"OpentelemetryProcessPropagator.Task.await_many/1","type":"function"},{"doc":"See Task.await_many/2 .","ref":"OpentelemetryProcessPropagator.Task.html#await_many/2","title":"OpentelemetryProcessPropagator.Task.await_many/2","type":"function"},{"doc":"See Task.child_spec/1 .","ref":"OpentelemetryProcessPropagator.Task.html#child_spec/1","title":"OpentelemetryProcessPropagator.Task.child_spec/1","type":"function"},{"doc":"See Task.completed/1 .","ref":"OpentelemetryProcessPropagator.Task.html#completed/1","title":"OpentelemetryProcessPropagator.Task.completed/1","type":"function"},{"doc":"See Task.ignore/1 .","ref":"OpentelemetryProcessPropagator.Task.html#ignore/1","title":"OpentelemetryProcessPropagator.Task.ignore/1","type":"function"},{"doc":"See Task.shutdown/1 .","ref":"OpentelemetryProcessPropagator.Task.html#shutdown/1","title":"OpentelemetryProcessPropagator.Task.shutdown/1","type":"function"},{"doc":"See Task.shutdown/2 .","ref":"OpentelemetryProcessPropagator.Task.html#shutdown/2","title":"OpentelemetryProcessPropagator.Task.shutdown/2","type":"function"},{"doc":"Starts a task with the current OpenTelemetry.Ctx.t/0 . See Task.start/1 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start/1","title":"OpentelemetryProcessPropagator.Task.start/1","type":"function"},{"doc":"Starts a task with the current OpenTelemetry.Ctx.t/0 . See Task.start/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start/3","title":"OpentelemetryProcessPropagator.Task.start/3","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given fun with the current OpenTelemetry.Ctx.t/0 attached. See Task.start_link/1 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link/1","title":"OpentelemetryProcessPropagator.Task.start_link/1","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given module , function , and args with the current OpenTelemetry.Ctx.t/0 attached. See Task.start_link/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link/3","title":"OpentelemetryProcessPropagator.Task.start_link/3","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given fun in a new linked span. See Task.start_link/1 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link_with_linked_span/3","title":"OpentelemetryProcessPropagator.Task.start_link_with_linked_span/3","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given module , function , and args in a new linked span. See Task.start_link/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.start_link_with_linked_span/5","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given fun in a new child span. See Task.start_link/1 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link_with_span/3","title":"OpentelemetryProcessPropagator.Task.start_link_with_span/3","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given module , function , and args in a new child span. See Task.start_link/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link_with_span/5","title":"OpentelemetryProcessPropagator.Task.start_link_with_span/5","type":"function"},{"doc":"Starts a task with a new linked span. See Task.start/1 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_with_linked_span/3","title":"OpentelemetryProcessPropagator.Task.start_with_linked_span/3","type":"function"},{"doc":"Starts a task with a new linked span. See Task.start/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.start_with_linked_span/5","type":"function"},{"doc":"Starts a task with a new child span. See Task.start/1 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_with_span/3","title":"OpentelemetryProcessPropagator.Task.start_with_span/3","type":"function"},{"doc":"Starts a task with a new child span. See Task.start/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_with_span/5","title":"OpentelemetryProcessPropagator.Task.start_with_span/5","type":"function"},{"doc":"See Task.yield/1 .","ref":"OpentelemetryProcessPropagator.Task.html#yield/1","title":"OpentelemetryProcessPropagator.Task.yield/1","type":"function"},{"doc":"See Task.yield/2 .","ref":"OpentelemetryProcessPropagator.Task.html#yield/2","title":"OpentelemetryProcessPropagator.Task.yield/2","type":"function"},{"doc":"See Task.yield_many/1 .","ref":"OpentelemetryProcessPropagator.Task.html#yield_many/1","title":"OpentelemetryProcessPropagator.Task.yield_many/1","type":"function"},{"doc":"See Task.yield_many/2 .","ref":"OpentelemetryProcessPropagator.Task.html#yield_many/2","title":"OpentelemetryProcessPropagator.Task.yield_many/2","type":"function"},{"doc":"OpentelemetryProcessPropagator.Task.Supervisor provides a set of extensions to the Task.Supervisor module to reduce some boilerplate in propagating OpenTelemetry contexts across process boundaries. Since these are extensions rather than a replacement of Elixir's module, this library can be aliased into a file without concern for creating spans where you do not want them. Each Task.Supervisor function is replicated with two variants: *_with_span and *_with_linked_span . Each of these variations has a specific use case. The original implementation for each function automatically propagates the current context. * - propagates the current context *_with_span - propagates the current context and starts a new child span. *_with_linked_span - propagates the current context and starts a new linked span. Module Redefinement This module does not redefine the Task.Supervisor module, instead providing a wrapper of the module, so this functionality will not globally modify the default behavior of the Task module.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html","title":"OpentelemetryProcessPropagator.Task.Supervisor","type":"module"},{"doc":"Starts a task with the current OpenTelemetry.Ctx.t/0 that can be awaited on. See Task.Supervisor.async/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async/3","title":"OpentelemetryProcessPropagator.Task.Supervisor.async/3","type":"function"},{"doc":"Starts a task with the current OpenTelemetry.Ctx.t/0 that can be awaited on. See Task.Supervisor.async/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async/5","type":"function"},{"doc":"Starts a task with the current OpenTelemetry.Ctx.t/0 that can be awaited on. See Task.Supervisor.async_nolink/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink/3","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink/3","type":"function"},{"doc":"Starts a task with the current OpenTelemetry.Ctx.t/0 that can be awaited on. See Task.Supervisor.async_nolink/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink/5","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on. See Task.Supervisor.async_nolink/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink_with_linked_span/5","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on. See Task.Supervisor.async_nolink/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink_with_linked_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink_with_linked_span/7","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on. See Task.Supervisor.async_nolink/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink_with_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink_with_span/5","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on. See Task.Supervisor.async_nolink/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink_with_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink_with_span/7","type":"function"},{"doc":"Returns a stream that runs the given function fun concurrently on each element in enumerable with the current OpenTelemetry.Ctx.t/0 attached. See Task.Supervisor.async_stream/4 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream/4","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream/4","type":"function"},{"doc":"Returns a stream where the given function ( module and function ) is mapped concurrently on each element in enumerable with the current OpenTelemetry.Ctx.t/0 attached. See Task.Supervisor.async_stream/6 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream/6","type":"function"},{"doc":"Returns a stream that runs the given function fun concurrently on each element in enumerable with the current OpenTelemetry.Ctx.t/0 attached. See Task.Supervisor.async_stream_nolink/4 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink/4","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink/4","type":"function"},{"doc":"Returns a stream where the given function ( module and function ) is mapped concurrently on each element in enumerable with the current OpenTelemetry.Ctx.t/0 attached. See Task.Supervisor.async_stream_nolink/6 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink/6","type":"function"},{"doc":"Returns a stream that runs the given function fun concurrently on each element in enumerable with a new linked span. See Task.Supervisor.async_stream_nolink/4 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink_with_linked_span/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink_with_linked_span/6","type":"function"},{"doc":"Returns a stream where the given function ( module and function ) is mapped concurrently on each element in enumerable with a new linked span. See Task.Supervisor.async_stream_nolink/6 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink_with_linked_span/8","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink_with_linked_span/8","type":"function"},{"doc":"Returns a stream that runs the given function fun concurrently on each element in enumerable with a new child span. See Task.Supervisor.async_stream_nolink/4 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink_with_span/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink_with_span/6","type":"function"},{"doc":"Returns a stream where the given function ( module and function ) is mapped concurrently on each element in enumerable with a new child span. See Task.Supervisor.async_stream_nolink/6 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink_with_span/8","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink_with_span/8","type":"function"},{"doc":"Returns a stream that runs the given function fun concurrently on each element in enumerable with a new linked span. See Task.Supervisor.async_stream/4 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_with_linked_span/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_with_linked_span/6","type":"function"},{"doc":"Returns a stream where the given function ( module and function ) is mapped concurrently on each element in enumerable with a new linked span. See Task.Supervisor.async_stream/6 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_with_linked_span/8","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_with_linked_span/8","type":"function"},{"doc":"Returns a stream that runs the given function fun concurrently on each element in enumerable with a new child span. See Task.Supervisor.async_stream/4 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_with_span/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_with_span/6","type":"function"},{"doc":"Returns a stream where the given function ( module and function ) is mapped concurrently on each element in enumerable with a new child span. See Task.Supervisor.async_stream/6 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_with_span/8","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_with_span/8","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on. See Task.Supervisor.async/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_with_linked_span/5","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on. See Task.Supervisor.async/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_with_linked_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_with_linked_span/7","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on. See Task.Supervisor.async/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_with_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_with_span/5","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on. See Task.Supervisor.async/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_with_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_with_span/7","type":"function"},{"doc":"See Task.Supervisor.children/1 .","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#children/1","title":"OpentelemetryProcessPropagator.Task.Supervisor.children/1","type":"function"},{"doc":"Starts a task as a child of the given supervisor with the current OpenTelemetry.Ctx.t/0 . See Task.Supervisor.start_child/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child/3","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child/3","type":"function"},{"doc":"Starts a task as a child of the given supervisor with the current OpenTelemetry.Ctx.t/0 . See Task.Supervisor.start_child/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child/5","type":"function"},{"doc":"Starts a task as a child of the given supervisor in a new linked span. See Task.Supervisor.start_child/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child_with_linked_span/5","type":"function"},{"doc":"Starts a task as a child of the given supervisor in a new linked span. See Task.Supervisor.start_child/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child_with_linked_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child_with_linked_span/7","type":"function"},{"doc":"Starts a task as a child of the given supervisor in a new child span. See Task.Supervisor.start_child/3 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child_with_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child_with_span/5","type":"function"},{"doc":"Starts a task as a child of the given supervisor in a new child span. See Task.Supervisor.start_child/5 for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child_with_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child_with_span/7","type":"function"},{"doc":"See Task.Supervisor.start_link/1 .","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_link/1","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_link/1","type":"function"},{"doc":"See Task.Supervisor.terminate_child/2 .","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#terminate_child/2","title":"OpentelemetryProcessPropagator.Task.Supervisor.terminate_child/2","type":"function"}]